﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Reflection;

namespace Diplomová_práce
{
  public partial class SettingsWindow : Form
  {
    private MainWindow mainw;

    public SettingsWindow(MainWindow mainw)
    {
      InitializeComponent();
      this.mainw = mainw;
      applySettings();
    }

    /// <summary>
    /// načtení nastavení programu
    /// </summary>
    private void applySettings()
    {
      foreach (KeyValuePair<string, string> pair in mainw.znakovaSada)
      {
        comboBoxKodovani.Items.Add(pair.Value);
      }
      comboBoxKodovani.SelectedItem = mainw.znakovaSada[mainw.cfg_znakovaSada];
      foreach (PropertyInfo color in typeof(System.Drawing.Color).GetProperties(BindingFlags.Static | BindingFlags.Public))
      {
        if (color.PropertyType == typeof(System.Drawing.Color))
        {
          comboBoxBarvaGrafu.Items.Add((Color)color.GetValue(null, null));
        }
      }
      comboBoxBarvaGrafu.SelectedItem = mainw.cfg_barvaGrafu;
      checkBoxTitulek.Checked = (mainw.cfg_title == 1) ? true : false;
      checkBoxZalamovani.Checked = (mainw.cfg_zalamovani == 1) ? true : false;
      checkBoxNekorektniHTML.Checked = (mainw.cfg_nekorektniHTML == 1) ? true : false;
      checkBoxCS.Checked = (mainw.cfg_vyrazCS == 1) ? true : false;
      checkBoxCetnost.Checked = (mainw.cfg_cetnost == 1) ? true : false;
      radioButtonCetnostVsechna.Checked = (mainw.cfg_cetnostRBtn == 0) ? true : false;
      radioButtonCetnostVlastni.Checked = (mainw.cfg_cetnostRBtn == 1) ? true : false;
      numericUpDownCetnostLimit.Value = mainw.cfg_cetnostLimit;
      numericUpDownCetnostDelka.Value = mainw.cfg_cetnostDelka;
      foreach (KeyValuePair<string, int> pair in mainw.cetnostVlastni)
      {
        listBoxCetnostVyrazy.Items.Add(pair.Key);
      }
    }

    /// <summary>
    /// ošetření výběru "-" v seznamu kódování
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void comboBoxKodovani_SelectedIndexChanged(object sender, EventArgs e)
    {
      if (comboBoxKodovani.SelectedIndex == 4)
      {
        comboBoxKodovani.SelectedIndex = 0;
      }
    }

    /// <summary>
    /// stisknutí tlačítka OK - uložení nastavení programu
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void okButton_Click(object sender, EventArgs e)
    {
      mainw.cfg_znakovaSada = mainw.znakovaSada.SingleOrDefault(x => x.Value == comboBoxKodovani.SelectedItem.ToString()).Key;
      mainw.cfg_barvaGrafu = (Color)comboBoxBarvaGrafu.SelectedItem;
      mainw.cfg_title = (checkBoxTitulek.Checked == true) ? 1 : 0;
      mainw.cfg_zalamovani = (checkBoxZalamovani.Checked == true) ? 1 : 0;
      mainw.cfg_nekorektniHTML = (checkBoxNekorektniHTML.Checked == true) ? 1 : 0;
      mainw.cfg_vyrazCS = (checkBoxCS.Checked == true) ? 1 : 0;
      mainw.cfg_cetnost = (checkBoxCetnost.Checked == true) ? 1 : 0;
      mainw.cfg_cetnostRBtn = (radioButtonCetnostVsechna.Checked == true) ? 0 : 1;
      mainw.cfg_cetnostLimit = (int)numericUpDownCetnostLimit.Value;
      mainw.cfg_cetnostDelka = (int)numericUpDownCetnostDelka.Value;
      foreach (string item in listBoxCetnostVyrazy.Items)
      {
        if (!mainw.cetnostVlastni.ContainsKey(item))
        {
          mainw.cetnostVlastni.Add(item, 0);
        }
      }
      foreach (string item in mainw.cetnostVlastni.Keys.ToList())
      {
        if (!listBoxCetnostVyrazy.Items.Contains(item))
        {
          mainw.cetnostVlastni.Remove(item);
        }
      }
      mainw.cfg_ok = 1;
      this.Close();
    }

    /// <summary>
    /// stisknutí tlačítka Storno - zavření okna nastavení programu bez uložení změn
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void stornoButton_Click(object sender, EventArgs e)
    {
      mainw.cfg_ok = 0;
      this.Close();
    }


    #region cetnost
    // ----------------------------------------------------------------------------------------- //
    //  ČETNOST
    // ----------------------------------------------------------------------------------------- //

    /// <summary>
    /// povolení nebo zakázání počítání četnosti
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void checkBoxCetnost_CheckedChanged(object sender, EventArgs e)
    {
      setComponentState();
    }

    /// <summary>
    /// vlastní seznam výrazů
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void radioButtonCetnostVlastni_CheckedChanged(object sender, EventArgs e)
    {
      setComponentState();
    }

    /// <summary>
    /// pomocná metoda pro nastavení aktivity komponent
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void setComponentState()
    {
      if (checkBoxCetnost.Checked == true)
      {
        labelCetnostPocet.Enabled = true;
        numericUpDownCetnostLimit.Enabled = true;
        labelCetnostDelka.Enabled = true;
        numericUpDownCetnostDelka.Enabled = true;
        radioButtonCetnostVsechna.Enabled = true;
        radioButtonCetnostVlastni.Enabled = true;
        if (radioButtonCetnostVlastni.Checked == true)
        {
          labelCetnostPocet.Enabled = false;
          numericUpDownCetnostLimit.Enabled = false;
          labelCetnostDelka.Enabled = false;
          numericUpDownCetnostDelka.Enabled = false;
          listBoxCetnostVyrazy.Enabled = true;
          labelCetnostVlastniVyraz.Enabled = true;
          textBoxVlastniVyraz.Enabled = true;
          buttonCetnostVlastniPridat.Enabled = true;
          buttonCetnostVlastniOdebrat.Enabled = true;
        }
        else
        {
          listBoxCetnostVyrazy.Enabled = false;
          labelCetnostVlastniVyraz.Enabled = false;
          textBoxVlastniVyraz.Enabled = false;
          buttonCetnostVlastniPridat.Enabled = false;
          buttonCetnostVlastniOdebrat.Enabled = false;
        }
      }
      else
      {
        labelCetnostPocet.Enabled = false;
        numericUpDownCetnostLimit.Enabled = false;
        labelCetnostDelka.Enabled = false;
        numericUpDownCetnostDelka.Enabled = false;
        radioButtonCetnostVsechna.Enabled = false;
        radioButtonCetnostVlastni.Enabled = false;
        listBoxCetnostVyrazy.Enabled = false;
        labelCetnostVlastniVyraz.Enabled = false;
        textBoxVlastniVyraz.Enabled = false;
        buttonCetnostVlastniPridat.Enabled = false;
        buttonCetnostVlastniOdebrat.Enabled = false;
      }
    }

    /// <summary>
    /// přidání vlastního výrazu do seznamu
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void buttonCetnostVlastniPridat_Click(object sender, EventArgs e)
    {
      if (textBoxVlastniVyraz.Text == "")
      {
        MessageBox.Show("Zadejte výraz pro přidání do seznamu!", mainw.Text, MessageBoxButtons.OK, MessageBoxIcon.Information);
      }
      else if (listBoxCetnostVyrazy.Items.Contains(textBoxVlastniVyraz.Text.Trim().ToLower()) == true)
      {
        MessageBox.Show("Zadaný výraz již v seznamu existuje, zadejte jiný výraz!", mainw.Text, MessageBoxButtons.OK, MessageBoxIcon.Information);
      }
      else if (listBoxCetnostVyrazy.Items.Count == 15)
      {
        MessageBox.Show("Seznam vlastních výrazů je plný! Kapacita je 15 výrazů.", mainw.Text, MessageBoxButtons.OK, MessageBoxIcon.Information);
      }
      else
      {
        listBoxCetnostVyrazy.Items.Add(textBoxVlastniVyraz.Text.Trim().ToLower());
        textBoxVlastniVyraz.Text = "";
      }
    }

    /// <summary>
    /// odebrání vybraného výrazu ze seznamu
    /// </summary>
    /// <param name="sender"></param>
    /// <param name="e"></param>
    private void buttonCetnostVlastniOdebrat_Click(object sender, EventArgs e)
    {
      if (listBoxCetnostVyrazy.SelectedIndex == -1)
      {
        MessageBox.Show("Vyberte výraz pro odebrání!", mainw.Text, MessageBoxButtons.OK, MessageBoxIcon.Information);
      }
      else
      {
        for (int i = listBoxCetnostVyrazy.SelectedItems.Count - 1; i >= 0; i--)
        {
          listBoxCetnostVyrazy.Items.Remove(listBoxCetnostVyrazy.SelectedItems[i]);
        }
      }
    }
    #endregion
  }
}
